;;; finder-inf.el --- keyword-to-package mapping (do not edit)   -*- lexical-binding: t -*-
;; Generated by the `finder-compile-keywords' function.

;; This file is part of GNU Emacs.

;;; Code:

(setq package--builtins '(
  (5x5 . [nil nil "simple little puzzle game"])
  (add-log . [nil nil "change log maintenance commands for Emacs"])
  (align . [nil nil "align text to a specific column, by regexp"])
  (allout . [(2 3) nil "extensive outline mode for use alone and with other modes"])
  (allout-widgets . [(1 0) nil "Visually highlight allout outline structure."])
  (ange-ftp . [nil nil "transparent FTP support for GNU Emacs"])
  (animate . [nil nil "make text dance"])
  (ansi-color . [(3 4 2) nil "translate ANSI escape sequences into faces"])
  (ansi-osc . [nil nil "Support for OSC escape sequences"])
  (antlr-mode . [(2 2 3) nil "major mode for ANTLR grammar files"])
  (arc-mode . [nil nil "simple editing of archives"])
  (array . [nil nil "array editing commands for GNU Emacs"])
  (artist . [nil nil "draw ascii graphics with your mouse"])
  (asm-mode . [nil nil "mode for editing assembler code"])
  (auth-source . [nil nil "authentication sources for Gnus and Emacs"])
  (auth-source-pass . [(5 0 0) nil "Integrate auth-source with password-store"])
  (autoconf . [nil nil "mode for editing Autoconf configure.ac files"])
  (autoinsert . [nil nil "automatic mode-dependent insertion of text into new files"])
  (autorevert . [nil nil "revert buffers when files on disk change"])
  (avl-tree . [nil nil "balanced binary trees, AVL-trees"])
  (avoid . [nil nil "make mouse pointer stay out of the way of editing"])
  (backtrace . [(1 0) nil "generic major mode for Elisp backtraces"])
  (bat-mode . [nil nil "Major mode for editing DOS/Windows scripts"])
  (battery . [nil nil "display battery status information"])
  (benchmark . [nil nil "support for benchmarking code"])
  (bib-mode . [nil nil "major mode for editing bib files"])
  (bibtex . [nil nil "BibTeX mode for GNU Emacs"])
  (bibtex-style . [nil nil "Major mode for BibTeX Style files"])
  (bind-key . [(2 4 1) nil "A simple way to manage personal keybindings"])
  (bindat . [nil nil "binary data structure packing and unpacking."])
  (binhex . [nil nil "decode BinHex-encoded text"])
  (blackbox . [nil nil "blackbox game in Emacs Lisp"])
  (bookmark . [nil nil "set bookmarks, maybe annotate them, jump to them later"])
  (browse-url . [nil nil "pass a URL to a web browser"])
  (bs . [nil nil "menu for selecting and displaying buffers"])
  (bubbles . [nil nil "Puzzle game for Emacs"])
  (bug-reference . [nil nil "buttonize bug references"])
  (c-ts-mode . [nil nil "tree-sitter support for C and C++"])
  (calc . [nil nil "the GNU Emacs calculator"])
  (calculator . [nil nil "a calculator for Emacs"])
  (calendar . [nil nil "calendar functions"])
  (cc-guess . [nil nil "guess indentation values by scanning existing code"])
  (cc-mode . [(5 33 1) nil "major mode for editing C and similar languages"])
  (cdl . [nil nil "Common Data Language (CDL) utility functions for GNU Emacs"])
  (cedet . [(2 0) nil "Setup CEDET environment"])
  (cfengine . [(1 4) nil "mode for editing Cfengine files"])
  (char-fold . [nil nil "match unicode to similar ASCII"])
  (chart . [nil nil "Draw charts (bar charts, etc)"])
  (check-declare . [nil nil "Check declare-function statements"])
  (checkdoc . [nil nil "check documentation strings for style requirements"])
  (chistory . [nil nil "list command history"])
  (cl-font-lock . [nil nil "Pretty Common Lisp font locking"])
  (cl-generic . [(1 0) nil "CLOS-style generic functions for Elisp"])
  (cl-lib . [(1 0) nil "Common Lisp extensions for Emacs"])
  (cl-print . [(1 0) nil "CL-style generic printing"])
  (cmacexp . [nil nil "expand C macros in a region"])
  (cmake-ts-mode . [nil nil "tree-sitter support for CMake"])
  (cmuscheme . [nil nil "Scheme process in a buffer. Adapted from tea.el"])
  (color . [nil nil "Color manipulation library"])
  (compare-w . [nil nil "compare text between windows for Emacs"])
  (compat . [(30 2 9999) nil "Stub of the Compatibility Library"])
  (compface . [nil nil "functions for converting X-Face headers"])
  (compile . [nil nil "run compiler as inferior of Emacs, parse error messages"])
  (completion . [nil nil "dynamic word-completion code"])
  (completion-preview . [nil nil "Preview completion with inline overlay"])
  (conf-mode . [nil nil "Simple major mode for editing conf/ini/properties files"])
  (cookie1 . [nil nil "retrieve random phrases from fortune cookie files"])
  (copyright . [nil nil "update the copyright notice in current buffer"])
  (cperl-mode . [nil nil "Perl code editing commands for Emacs"])
  (cpp . [nil nil "highlight or hide text according to cpp conditionals"])
  (crm . [nil nil "read multiple strings with completion"])
  (csharp-mode . [nil nil "Support for editing C#"])
  (css-mode . [nil nil "Major mode to edit CSS files"])
  (cua-base . [nil nil "emulate CUA key bindings"])
  (cursor-sensor . [nil nil "React to cursor movement"])
  (cvs-status . [nil nil "major mode for browsing `cvs status' output"])
  (cwarn . [nil nil "highlight suspicious C and C++ constructions"])
  (dabbrev . [nil nil "dynamic abbreviation package"])
  (dbus . [nil nil "Elisp bindings for D-Bus."])
  (dcl-mode . [nil nil "major mode for editing DCL command files"])
  (debug . [nil nil "debuggers and related commands for Emacs"])
  (decipher . [nil nil "cryptanalyze monoalphabetic substitution ciphers"])
  (delim-col . [nil nil "prettify all columns in a region or rectangle"])
  (delsel . [nil nil "delete selection if you insert"])
  (descr-text . [nil nil "describe text mode"])
  (desktop . [nil nil "save partial status of Emacs when killed"])
  (dframe . [nil nil "dedicate frame support modes"])
  (diary-lib . [nil nil "diary functions"])
  (dictionary . [nil nil "Client for rfc2229 dictionary servers"])
  (dictionary-connection . [nil nil "TCP-based client connection for dictionary"])
  (diff . [nil nil "run `diff'"])
  (diff-mode . [nil nil "a mode for viewing/editing context diffs"])
  (dig . [nil nil "Domain Name System dig interface"])
  (dirtrack . [nil nil "Directory Tracking by watching the prompt"])
  (disass . [nil nil "disassembler for compiled Emacs Lisp code"])
  (display-fill-column-indicator . [nil nil "interface for display-fill-column-indicator"])
  (display-line-numbers . [nil nil "interface for display-line-numbers"])
  (dissociate . [nil nil "scramble text amusingly for Emacs"])
  (dns . [nil nil "Domain Name Service lookups"])
  (dns-mode . [nil nil "a mode for viewing/editing Domain Name System master files"])
  (doc-view . [nil nil "Document viewer for Emacs"])
  (dockerfile-ts-mode . [nil nil "tree-sitter support for Dockerfiles"])
  (doctor . [nil nil "psychological help for frustrated users"])
  (dom . [nil nil "XML/HTML (etc.) DOM manipulation and searching functions"])
  (double . [nil nil "support for keyboard remapping with double clicking"])
  (dunnet . [nil nil "text adventure for Emacs"])
  (ebnf2ps . [nil nil "translate an EBNF to a syntactic chart on PostScript"])
  (ebrowse . [nil nil "Emacs C++ class browser & tags facility"])
  (ebuff-menu . [nil nil "electric-buffer-list mode"])
  (echistory . [nil nil "Electric Command History Mode"])
  (ecomplete . [nil nil "electric completion of addresses and the like"])
  (ede . [(2 0) nil "Emacs Development Environment gloss"])
  (edebug . [nil nil "a source-level debugger for Emacs Lisp"])
  (ediff . [(2 81 6) nil "a comprehensive visual interface to diff & patch"])
  (editorconfig . [(0 11 0) nil "EditorConfig Plugin"])
  (edmacro . [nil nil "keyboard macro editor"])
  (edt . [nil nil "enhanced EDT keypad mode emulation for GNU Emacs"])
  (eglot . [(1 17 30) nil "The Emacs Client for LSP servers"])
  (ehelp . [nil nil "bindings for electric-help mode"])
  (eieio . [(1 4) nil "Enhanced Implementation of Emacs Interpreted Objects"])
  (eieio-core . [(1 4) nil "Core implementation for eieio"])
  (eldoc . [(1 15 0) nil "Show function arglist or variable docstring in echo area"])
  (elec-pair . [nil nil "Automatically insert matching delimiters"])
  (electric . [nil nil "window maker and Command loop for `electric' modes"])
  (elide-head . [nil nil "hide headers in files"])
  (elint . [nil nil "Lint Emacs Lisp"])
  (elixir-ts-mode . [nil nil "Major mode for Elixir with tree-sitter support"])
  (elp . [nil nil "Emacs Lisp Profiler"])
  (emacs . [(30 2) nil "the extensible text editor"])
  (emacs-authors-mode . [nil nil "font-locking for etc/AUTHORS"])
  (emacs-lock . [nil nil "protect buffers against killing or exiting"])
  (emacs-news-mode . [nil nil "major mode to edit and view the NEWS file"])
  (emerge . [nil nil "merge diffs under Emacs control"])
  (enriched . [nil nil "read and save files in text/enriched format"])
  (epa . [nil nil "the EasyPG Assistant"])
  (epg . [(1 0 0) nil "the EasyPG Library"])
  (erc . [(5 6 0 30 1) nil "An Emacs Internet Relay Chat client"])
  (ert . [nil nil "Emacs Lisp Regression Testing"])
  (ert-font-lock . [nil nil "ERT Font Lock"])
  (ert-x . [nil nil "Staging area for experimental extensions to ERT"])
  (erts-mode . [nil nil "major mode to edit erts files"])
  (eshell . [(2 4 2) nil "the Emacs command shell"])
  (etags . [nil nil "etags facility for Emacs"])
  (etags-regen . [nil nil "Auto-(re)regenerating tags"])
  (eudc . [nil nil "Emacs Unified Directory Client"])
  (ewoc . [nil nil "utility to maintain a view of a list of objects in a buffer"])
  (eww . [nil nil "Emacs Web Wowser"])
  (executable . [nil nil "base functionality for executable interpreter scripts"])
  (exif . [nil nil "parsing Exif data in JPEG images"])
  (expand . [nil nil "make abbreviations more usable"])
  (external-completion . [(0 1) nil "Let external tools control completion style"])
  (ezimage . [nil nil "Generalized Image management"])
  (f90 . [nil nil "Fortran-90 mode (free format)"])
  (face-remap . [nil nil "Functions for managing `face-remapping-alist'"])
  (faceup . [(0 0 6) nil "Markup language for faces and font-lock regression testing"])
  (feedmail . [(11) nil "assist other email packages to massage outgoing messages"])
  (ffap . [nil nil "find file (or url) at point"])
  (filecache . [nil nil "find files using a pre-loaded cache"])
  (fileloop . [nil nil "Operations on multiple files"])
  (filenotify . [nil nil "watch files for changes on disk"])
  (filesets . [nil nil "handle group of files"])
  (find-cmd . [(0 6) nil "Build a valid find(1) command with sexps"])
  (find-dired . [nil nil "run a `find' command and dired the output"])
  (find-file . [nil nil "find a file corresponding to this one given a pattern"])
  (find-func . [nil nil "find the definition of the Emacs Lisp function near point"])
  (find-lisp . [nil nil "emulation of find in Emacs Lisp"])
  (finder . [nil nil "topic & keyword-based code finder"])
  (flow-ctrl . [nil nil "help for lusers on cu(1) or ttys with wired-in ^S/^Q flow control"])
  (flow-fill . [nil nil "interpret RFC2646 \"flowed\" text"])
  (flymake . [(1 3 7) nil "A universal on-the-fly syntax checker"])
  (flymake-cc . [nil nil "Flymake support for GNU tools for C/C++"])
  (flymake-proc . [(1 0) nil "Flymake backend for external tools"])
  (flyspell . [nil nil "On-the-fly spell checker"])
  (foldout . [(1 10) nil "folding extensions for outline-mode and outline-minor-mode"])
  (follow . [nil nil "synchronize windows showing the same buffer"])
  (footnote . [nil nil "footnote support for message mode"])
  (format-spec . [nil nil "format arbitrary formatting strings"])
  (forms . [nil nil "Forms mode: edit a file as a form to fill in"])
  (fortran . [nil nil "Fortran mode for GNU Emacs"])
  (fortune . [nil nil "use fortune to create signatures"])
  (frameset . [nil nil "save and restore frame and window setup"])
  (gamegrid . [nil nil "library for implementing grid-based games on Emacs"])
  (gametree . [nil nil "manage game analysis trees in Emacs"])
  (gdb-mi . [nil nil "User Interface for running GDB"])
  (glasses . [nil nil "make cantReadThis readable"])
  (glyphless-mode . [nil nil "minor mode for displaying glyphless characters"])
  (gnus . [(5 13) nil "a newsreader for GNU Emacs"])
  (gnutls . [nil nil "Support SSL/TLS connections through GnuTLS"])
  (go-ts-mode . [nil nil "tree-sitter support for Go"])
  (gomoku . [nil nil "Gomoku game between you and Emacs"])
  (goto-addr . [nil nil "click to browse URL or to send to e-mail address"])
  (gravatar . [nil nil "Get Gravatars"])
  (grep . [nil nil "run `grep' and display the results"])
  (gud . [nil nil "Grand Unified Debugger mode for running GDB and other debuggers"])
  (handwrite . [nil nil "turns your emacs buffer into a handwritten document"])
  (hanoi . [nil nil "towers of hanoi in Emacs"])
  (hashcash . [nil nil "Add hashcash payments to email"])
  (heex-ts-mode . [nil nil "Major mode for Heex with tree-sitter support"])
  (help-at-pt . [nil nil "local help through the keyboard"])
  (hex-util . [nil nil "Functions to encode/decode hexadecimal string"])
  (hexl . [nil nil "edit a file in a hex dump format using the hexl filter"])
  (hi-lock . [nil nil "minor mode for interactive automatic highlighting"])
  (hideif . [nil nil "hides selected code within ifdef"])
  (hideshow . [nil nil "minor mode cmds to selectively display code/comment blocks"])
  (hierarchy . [nil nil "Library to create and display hierarchical structures"])
  (hilit-chg . [nil nil "minor mode displaying buffer changes with special face"])
  (hippie-exp . [nil nil "expand text trying various ways to find its expansion"])
  (hl-line . [nil nil "highlight the current line"])
  (hmac-def . [nil nil "A macro for defining HMAC functions."])
  (hmac-md5 . [nil nil "Compute HMAC-MD5."])
  (html-ts-mode . [nil nil "tree-sitter support for HTML"])
  (htmlfontify . [nil nil "htmlize a buffer/source tree with optional hyperlinks"])
  (ibuffer . [nil nil "operate on buffers like dired"])
  (icalendar . [nil nil "iCalendar implementation"])
  (icomplete . [nil nil "minibuffer completion incremental feedback"])
  (icon . [nil nil "mode for editing Icon code"])
  (icons . [nil nil "Handling icons"])
  (idlwave . [(6 1 22) nil "IDL editing mode for GNU Emacs"])
  (ido . [nil nil "interactively do things with buffers and files"])
  (ielm . [nil nil "interaction mode for Emacs Lisp"])
  (ietf-drums . [nil nil "Functions for parsing RFC 2822 headers"])
  (iimage . [nil nil "Inline image minor mode."])
  (image-converter . [nil nil "Converting images from exotic formats"])
  (image-crop . [nil nil "Image Cropping"])
  (image-dired . [(0 5) nil "use dired to browse and manipulate your images"])
  (image-file . [nil nil "support for visiting image files"])
  (imap . [nil nil "imap library"])
  (imenu . [nil nil "framework for mode-specific buffer indexes"])
  (inf-lisp . [nil nil "an inferior-lisp mode"])
  (info . [nil nil "Info package for Emacs"])
  (info-look . [nil nil "major-mode-sensitive Info index lookup facility"])
  (info-xref . [(3) nil "check external references in an Info document"])
  (informat . [nil nil "info support functions package for Emacs"])
  (inline . [nil nil "Define functions by their inliner"])
  (isearchb . [(1 5) nil "a marriage between iswitchb and isearch"])
  (iso8601 . [nil nil "parse ISO 8601 date/time strings"])
  (ispell . [nil nil "interface to spell checkers"])
  (java-ts-mode . [nil nil "tree-sitter support for Java"])
  (jka-compr . [nil nil "reading/writing/loading compressed files"])
  (js . [(9) nil "Major mode for editing JavaScript"])
  (json . [(1 5) nil "JavaScript Object Notation parser / generator"])
  (json-ts-mode . [nil nil "tree-sitter support for JSON"])
  (jsonrpc . [(1 0 25) nil "JSON-RPC library"])
  (kermit . [nil nil "additions to shell mode for use with kermit"])
  (keypad . [nil nil "simplified keypad bindings"])
  (kmacro . [nil nil "enhanced keyboard macros"])
  (ld-script . [nil nil "GNU linker script editing mode for Emacs"])
  (ldap . [nil nil "client interface to LDAP for Emacs"])
  (less-css-mode . [nil nil "Major mode for editing Less CSS files"])
  (let-alist . [(1 0 6) nil "Easily let-bind values of an assoc-list by their names"])
  (life . [nil nil "John Horton Conway's Game of Life"])
  (lisp-mnt . [nil nil "utility functions for Emacs Lisp maintainers"])
  (loadhist . [nil nil "lisp functions for working with feature groups"])
  (locate . [nil nil "interface to the locate command"])
  (log-edit . [nil nil "Major mode for editing CVS commit messages"])
  (log-view . [nil nil "Major mode for browsing revision log histories"])
  (lpr . [nil nil "print Emacs buffer on line printer"])
  (lua-ts-mode . [nil nil "Major mode for editing Lua files"])
  (m4-mode . [nil nil "m4 code editing commands for Emacs"])
  (macroexp . [nil nil "Additional macro-expansion support"])
  (mail-parse . [nil nil "Interface functions for parsing mail"])
  (mail-prsvr . [nil nil "Interface variables for parsing mail"])
  (mail-utils . [nil nil "utility functions used both by rmail and rnews"])
  (mailabbrev . [nil nil "abbrev-expansion of mail aliases"])
  (mailalias . [nil nil "expand and complete mailing address aliases"])
  (mailcap . [nil nil "MIME media types configuration"])
  (mailclient . [nil nil "mail sending via system's mail client."])
  (mairix . [nil nil "Mairix interface for Emacs"])
  (make-mode . [nil nil "makefile editing commands for Emacs"])
  (makeinfo . [nil nil "run makeinfo conveniently"])
  (man . [nil nil "browse UNIX manual pages"])
  (map . [(3 3 1) nil "Map manipulation functions"])
  (master . [nil nil "make a buffer the master over another buffer"])
  (mb-depth . [nil nil "Indicate minibuffer-depth in prompt"])
  (md4 . [nil nil "MD4 Message Digest Algorithm."])
  (memory-report . [nil nil "Short function summaries"])
  (meta-mode . [(1 0) nil "major mode for editing Metafont or MetaPost sources"])
  (mh-e . [(8 6 -4) nil "GNU Emacs interface to the MH mail system"])
  (mhtml-mode . [nil nil "HTML editing mode that handles CSS and JS"])
  (midnight . [nil nil "run something every midnight, e.g., kill old buffers"])
  (minibuf-eldef . [nil nil "Only show defaults in prompts when applicable"])
  (misearch . [nil nil "isearch extensions for multi-buffer search"])
  (mixal-mode . [(0 4) nil "Major mode for the mix asm language."])
  (mode-local . [nil nil "Support for mode local facilities"])
  (modula2 . [nil nil "Modula-2 editing support package"])
  (morse . [nil nil "convert text to morse code and back"])
  (mouse-copy . [nil nil "one-click text copy and move"])
  (mouse-drag . [nil nil "use mouse-2 to do a new style of scrolling"])
  (mpc . [nil nil "A client for the Music Player Daemon"])
  (mpuz . [nil nil "multiplication puzzle for GNU Emacs"])
  (msb . [nil nil "customizable buffer-selection with multiple menus"])
  (mspools . [nil nil "show mail spools waiting to be read"])
  (multisession . [nil nil "Multisession storage for variables"])
  (nadvice . [(1 0) nil "Light-weight advice primitives for Elisp functions"])
  (net-utils . [nil nil "network functions"])
  (network-stream . [nil nil "open network processes, possibly with encryption"])
  (newsticker . [nil nil "A Newsticker for Emacs."])
  (notifications . [nil nil "Client interface to desktop notifications."])
  (novice . [nil nil "handling of disabled commands (\"novice mode\") for Emacs"])
  (nroff-mode . [nil nil "GNU Emacs major mode for editing nroff source"])
  (nsm . [nil nil "Network Security Manager"])
  (ntlm . [(2 1 0) nil "NTLM (NT LanManager) authentication support"])
  (nxml . [nil nil "a new XML mode"])
  (octave . [nil nil "editing octave source files under emacs"])
  (opascal . [nil nil "major mode for editing Object Pascal source in Emacs"])
  (org . [(9 7 11) nil "Outline-based notes management and organizer"])
  (outline . [nil nil "outline mode commands for Emacs"])
  (package . [(1 1 0) nil "Simple package system for Emacs"])
  (package-vc . [nil nil "Manage packages from VC checkouts"])
  (page-ext . [nil nil "extended page handling commands"])
  (paren . [nil nil "highlight matching paren"])
  (parse-time . [nil nil "parsing time strings"])
  (pascal . [nil nil "major mode for editing pascal source in Emacs"])
  (password-cache . [nil nil "Read passwords, possibly using a password cache."])
  (pcase . [nil nil "ML-style pattern-matching macro for Elisp"])
  (pcomplete . [nil nil "programmable completion"])
  (pcvs . [nil nil "a front-end to CVS"])
  (peg . [(1 0 1) nil "Parsing Expression Grammars in Emacs Lisp"])
  (perl-mode . [nil nil "Perl code editing commands for GNU Emacs"])
  (php-ts-mode . [nil nil "Major mode for editing PHP files using tree-sitter"])
  (picture . [nil nil "\"Picture mode\" -- editing using quarter-plane screen model"])
  (pixel-fill . [nil nil "variable pitch filling functions"])
  (plstore . [nil nil "secure plist store"])
  (po . [nil nil "basic support of PO translation files"])
  (pong . [nil nil "classical implementation of pong"])
  (pop3 . [nil nil "Post Office Protocol (RFC 1460) interface"])
  (pp . [nil nil "pretty printer for Emacs Lisp"])
  (printing . [nil nil "printing utilities"])
  (proced . [nil nil "operate on system processes like dired"])
  (profiler . [nil nil "UI and helper functions for Emacs's native profiler"])
  (project . [(0 11 1) nil "Operations on the current project"])
  (prolog . [nil nil "major mode for Prolog (and Mercury)"])
  (ps-mode . [(1 1 9) nil "PostScript mode for GNU Emacs"])
  (ps-print . [nil nil "print text from the buffer as PostScript"])
  (pulse . [(1 0) nil "Pulsing Overlays"])
  (puny . [nil nil "translate non-ASCII domain names to ASCII"])
  (python . [(0 28) nil "Python's flying circus support for Emacs"])
  (qp . [nil nil "Quoted-Printable functions"])
  (radix-tree . [nil nil "A simple library of radix trees"])
  (range . [nil nil "range functions"])
  (rcirc . [nil nil "default, simple IRC client"])
  (re-builder . [nil nil "building Regexps with visual feedback"])
  (recentf . [nil nil "keep track of recently opened files"])
  (refbib . [nil nil "convert refer-style references to ones usable by Latex bib"])
  (refer . [nil nil "look up references in bibliography files"])
  (refill . [nil nil "`auto-fill' by refilling paragraphs on changes"])
  (reftex . [nil nil "minor mode for doing \\label, \\ref, \\cite, \\index in LaTeX"])
  (reftex-auc . [nil nil "RefTeX's interface to AUCTeX"])
  (reftex-cite . [nil nil "creating citations with RefTeX"])
  (reftex-dcr . [nil nil "viewing cross references and citations with RefTeX"])
  (reftex-global . [nil nil "operations on entire documents with RefTeX"])
  (reftex-index . [nil nil "index support with RefTeX"])
  (reftex-parse . [nil nil "parser functions for RefTeX"])
  (reftex-ref . [nil nil "code to create labels and references with RefTeX"])
  (reftex-sel . [nil nil "the selection modes for RefTeX"])
  (reftex-toc . [nil nil "RefTeX's table of contents mode"])
  (reftex-vars . [nil nil "configuration variables for RefTeX"])
  (regexp-opt . [nil nil "generate efficient regexps to match strings"])
  (regi . [nil nil "REGular expression Interpreting engine"])
  (registry . [nil nil "Track and remember data items by various fields"])
  (remember . [nil nil "a mode for quickly jotting down things to remember"])
  (repeat . [nil nil "convenient way to repeat the previous command"])
  (reporter . [nil nil "customizable bug reporting of lisp programs"])
  (reposition . [nil nil "center a Lisp function or comment on the screen"])
  (reveal . [nil nil "Automatically reveal hidden text at point"])
  (rfc2045 . [nil nil "Functions for decoding rfc2045 headers"])
  (rfc2047 . [nil nil "functions for encoding and decoding rfc2047 messages"])
  (rfc2104 . [nil nil "RFC2104 Hashed Message Authentication Codes"])
  (rfc2231 . [nil nil "Functions for decoding rfc2231 headers"])
  (rfc6068 . [nil nil "support for rfc6068"])
  (rfc822 . [nil nil "hairy RFC 822 (or later) parser for mail, news, etc."])
  (ring . [nil nil "handle rings of items"])
  (rmail . [nil nil "main code of \"RMAIL\" mail reader for Emacs"])
  (rmc . [nil nil "read from a multiple choice question"])
  (rot13 . [nil nil "display a buffer in ROT13"])
  (rst . [nil nil "Mode for viewing and editing reStructuredText-documents"])
  (rtree . [nil nil "functions for manipulating range trees"])
  (ruby-mode . [(1 2) nil "Major mode for editing Ruby files"])
  (ruby-ts-mode . [(0 2) nil "Major mode for editing Ruby files using tree-sitter"])
  (ruler-mode . [nil nil "display a ruler in the header line"])
  (rust-ts-mode . [nil nil "tree-sitter support for Rust"])
  (rx . [nil nil "S-exp notation for regexps           -"])
  (sasl . [nil nil "SASL client framework"])
  (savehist . [nil nil "Save minibuffer history"])
  (saveplace . [nil nil "automatically save place in files"])
  (scheme . [nil nil "Scheme (and DSSSL) editing mode"])
  (scroll-all . [nil nil "scroll all buffers together minor mode"])
  (scroll-lock . [nil nil "Scroll lock scrolling."])
  (secrets . [nil nil "Client interface to gnome-keyring and kwallet."])
  (select . [nil nil "lisp portion of standard selection support"])
  (semantic . [(2 2) nil "Semantic buffer evaluator."])
  (sendmail . [nil nil "mail sending commands for Emacs"])
  (seq . [(2 24) nil "Sequence manipulation functions"])
  (server . [nil nil "Lisp code for GNU Emacs running as server process"])
  (ses . [nil nil "Simple Emacs Spreadsheet"])
  (sgml-mode . [nil nil "SGML- and HTML-editing modes"])
  (sh-script . [nil nil "shell-script editing commands for Emacs"])
  (shadow . [nil nil "locate Emacs Lisp file shadowings"])
  (shadowfile . [nil nil "automatic file copying"])
  (shell . [nil nil "specialized comint.el for running the shell"])
  (shr . [nil nil "Simple HTML Renderer"])
  (shr-color . [nil nil "Simple HTML Renderer color management"])
  (sieve . [nil nil "Utilities to manage sieve scripts"])
  (sieve-manage . [nil nil "Implementation of the managesieve protocol in elisp"])
  (sieve-mode . [nil nil "Sieve code editing commands for Emacs"])
  (simula . [nil nil "SIMULA 87 code editing commands for Emacs"])
  (skeleton . [nil nil "Lisp language extension for writing statement skeletons"])
  (smerge-mode . [nil nil "Minor mode to resolve diff3 conflicts"])
  (smie . [nil nil "Simple Minded Indentation Engine"])
  (smtpmail . [nil nil "simple SMTP protocol (RFC 821) for sending mail"])
  (snake . [nil nil "implementation of Snake for Emacs"])
  (snmp-mode . [nil nil "SNMP & SNMPv2 MIB major mode"])
  (so-long . [(1 1 2) nil "Say farewell to performance problems with minified code."])
  (soap-client . [(3 2 3) nil "Access SOAP web services"])
  (socks . [nil nil "A Socks v5 Client for Emacs"])
  (solitaire . [nil nil "game of solitaire in Emacs Lisp"])
  (sort . [nil nil "commands to sort text in an Emacs buffer"])
  (soundex . [nil nil "implement Soundex algorithm"])
  (speedbar . [nil nil "quick access to files and tags in a frame"])
  (spook . [nil nil "spook phrase utility for overloading the NSA line eater"])
  (sql . [(3 6) nil "specialized comint.el for SQL interpreters"])
  (sqlite . [nil nil "Functions for interacting with sqlite3 databases"])
  (sqlite-mode . [nil nil "Mode for examining sqlite3 database files"])
  (srecode . [(1 2) nil "Semantic buffer evaluator."])
  (string-edit . [nil nil "editing long strings"])
  (strokes . [nil nil "control Emacs through mouse strokes"])
  (studly . [nil nil "StudlyCaps (tm)(r)(c)(xxx)"])
  (subword . [nil nil "Handling capitalized subwords in a nomenclature"])
  (supercite . [nil nil "minor mode for citing mail and news replies"])
  (svg . [(1 1) nil "SVG image creation functions"])
  (syntax . [nil nil "helper functions to find syntactic context"])
  (t-mouse . [nil nil "mouse support within the text terminal"])
  (tab-bar . [nil nil "frame-local tabs with named persistent window configurations"])
  (tab-line . [nil nil "window-local tabs with window buffers"])
  (table . [nil nil "create and edit WYSIWYG text based embedded tables"])
  (tabulated-list . [(1 0) nil "generic major mode for tabulated lists"])
  (talk . [nil nil "allow several users to talk to each other through Emacs"])
  (tar-mode . [nil nil "simple editing of tar files from GNU Emacs"])
  (tcl . [nil nil "Tcl code editing commands for Emacs"])
  (telnet . [nil nil "run a telnet session from within an Emacs buffer"])
  (tempo . [nil nil "Flexible template insertion"])
  (term . [nil nil "general command interpreter in a window stuff"])
  (testcover . [nil nil "Visual code-coverage tool"])
  (tetris . [nil nil "implementation of Tetris for Emacs"])
  (tex-mode . [nil nil "TeX, LaTeX, and SliTeX mode commands"])
  (texinfmt . [nil nil "format Texinfo files into Info files"])
  (texinfo . [nil nil "major mode for editing Texinfo files"])
  (texnfo-upd . [nil nil "utilities for updating nodes and menus in Texinfo files"])
  (text-property-search . [nil nil "search for text properties"])
  (thingatpt . [nil nil "get the `thing' at point"])
  (thread . [nil nil "Thread support in Emacs Lisp"])
  (thunk . [(1 0) nil "Lazy form evaluation"])
  (tildify . [(4 6 1) nil "adding hard spaces into texts"])
  (time . [nil nil "display time, load and mail indicator in mode line of Emacs"])
  (time-date . [nil nil "Date and time handling functions"])
  (time-stamp . [nil nil "Maintain last change time stamps in files edited by Emacs"])
  (timeclock . [nil nil "mode for keeping track of how much you work"])
  (timezone . [nil nil "time zone package for GNU Emacs"])
  (tmm . [nil nil "text mode access to menu-bar"])
  (todo-mode . [nil nil "facilities for making and maintaining todo lists"])
  (toml-ts-mode . [nil nil "tree-sitter support for TOML"])
  (tq . [nil nil "utility to maintain a transaction queue"])
  (trace . [nil nil "tracing facility for Emacs Lisp functions"])
  (track-changes . [(1 2) nil "API to react to buffer modifications"])
  (tramp . [(0) nil "Transparent Remote Access, Multiple Protocol"])
  (transient . [(0 7 2 2) nil "Transient commands"])
  (tree-widget . [nil nil "Tree widget"])
  (two-column . [nil nil "minor mode for editing of two-column text"])
  (type-break . [nil nil "encourage rests from typing at appropriate intervals"])
  (typescript-ts-mode . [nil nil "tree sitter support for TypeScript"])
  (underline . [nil nil "insert/remove underlining (done by overstriking) in Emacs"])
  (undigest . [nil nil "digest-cracking support for the RMAIL mail reader"])
  (unrmail . [nil nil "convert Rmail Babyl files to mbox files"])
  (unsafep . [nil nil "Determine whether a Lisp form is safe to evaluate"])
  (url . [nil nil "Uniform Resource Locator retrieval tool"])
  (use-package . [(2 4 6) nil "A configuration macro for simplifying your .emacs"])
  (uudecode . [nil nil "elisp native uudecode"])
  (vc . [nil nil "drive a version-control system from within Emacs"])
  (vcursor . [nil nil "manipulate an alternative (\"virtual\") cursor"])
  (vera-mode . [(2 28) nil "major mode for editing Vera files"])
  (verilog-mode . [(2024 3 1 121933719) nil "major mode for editing verilog source in Emacs"])
  (vhdl-mode . [nil nil "major mode for editing VHDL code"])
  (view . [nil nil "peruse file or buffer without editing"])
  (viper . [(3 14 2) nil "A full-featured Vi emulator for Emacs"])
  (vtable . [nil nil "Displaying data in tables"])
  (wallpaper . [nil nil "Change the desktop background"])
  (warnings . [nil nil "log and display warnings"])
  (wdired . [nil nil "Rename files editing their names in dired buffers"])
  (webjump . [nil nil "programmable Web hotlist"])
  (which-func . [nil nil "print current function in mode line"])
  (which-key . [(3 6 0) nil "Display available keybindings in popup"])
  (whitespace . [(13 2 2) nil "minor mode to visualize TAB, (HARD) SPACE, NEWLINE"])
  (windmove . [nil nil "directional window-selection routines"])
  (window-tool-bar . [(0 2 1) nil "Add tool bars inside windows"])
  (winner . [nil nil "Restore old window configurations"])
  (woman . [nil nil "browse UN*X manual pages `wo (without) man'"])
  (word-wrap-mode . [nil nil "minor mode for `word-wrap' tweaks"])
  (xdg . [nil nil "XDG specification and standard support"])
  (xml . [nil nil "XML parser"])
  (xref . [(1 7 0) nil "Cross-referencing commands"])
  (xscheme . [nil nil "run MIT Scheme under Emacs"])
  (xt-mouse . [nil nil "support the mouse when emacs run in an xterm"])
  (xwidget . [nil nil "api functions for xwidgets"])
  (yaml-ts-mode . [nil nil "tree-sitter support for YAML"])
  (yank-media . [nil nil "Yanking images and HTML"])
  (yenc . [nil nil "elisp native yenc decoder"])
  (zeroconf . [nil nil "Service browser using Avahi."])
  (zone . [nil nil "idle display hacks"])
))

(setq finder-keywords-hash
      #s(hash-table test eq data (abbrev (tempo skeleton pcomplete emacs icomplete hippie-exp expand edmacro dabbrev completion completion-preview) convenience (diff-mode compare-w use-package table picture emacs makeinfo flyspell eglot cl-font-lock keypad cua-base text-property-search calc winner windmove vcursor tmm so-long scroll-all savehist ruler-mode repeat pcomplete minibuf-eldef mb-depth kmacro json imenu ido ibuffer hippie-exp frameset follow filesets filecache ffap editorconfig ebuff-menu display-line-numbers display-fill-column-indicator desktop delsel delim-col dabbrev completion completion-preview chistory calculator bs bookmark autorevert autoinsert align) languages (yaml-ts-mode toml-ts-mode sgml-mode mhtml-mode html-ts-mode xscheme vhdl-mode verilog-mode vera-mode typescript-ts-mode tcl sql simula sh-script scheme rust-ts-mode ruby-ts-mode ruby-mode python ps-mode perl-mode pascal opascal octave modula2 mixal-mode meta-mode m4-mode lua-ts-mode ld-script json-ts-mode js java-ts-mode idlwave icon heex-ts-mode go-ts-mode fortran flymake flymake-proc flymake-cc f90 executable elixir-ts-mode emacs eglot dockerfile-ts-mode dcl-mode cwarn csharp-mode cperl-mode cmake-ts-mode cfengine cc-mode cc-guess c-ts-mode bat-mode autoconf asm-mode antlr-mode nxml smie faceup tempo skeleton paren jsonrpc info-look allout align) lisp (xscheme scheme inf-lisp hideshow emacs cl-font-lock org unsafep trace testcover tabulated-list smie shadow re-builder pp nadvice memory-report map macroexp let-alist ewoc ert ert-font-lock elp elint eieio eieio-core edebug debug compat checkdoc check-declare benchmark backtrace cedet strokes profiler isearchb ielm color cmuscheme align) outlines (hideshow hideif org reveal outline foldout elide-head allout allout-widgets) text (underline two-column tildify emacs table sgml-mode refill picture page-ext nroff-mode mhtml-mode enriched ebnf2ps cl-font-lock handwrite org nxml whitespace ps-print printing delim-col allout) pgp (gnus plstore epg epa emacs allout) gnupg (plstore epg epa emacs allout) comm (url sgml-mode mhtml-mode dns-mode sql zeroconf webjump tramp telnet socks soap-client secrets rcirc ntlm net-utils ldap gnutls eudc dns dig dbus ange-ftp gravatar erc bindat talk shadowfile notifications master kermit ansi-color) processes (url sql inf-lisp idlwave grep compile tramp eshell bindat term shell server proced pcomplete jsonrpc emacs emacs-lock dirtrack cmuscheme ansi-osc ansi-color) terminals (tramp xt-mouse ansi-osc ansi-color) services (ansi-osc ansi-color) help (emacs memory-report woman novice man informat info info-look icomplete help-at-pt finder ehelp) files (compare-w po cl-font-lock xdg wdired view emacs shadowfile recentf locate ffap doc-view arc-mode) archives (arc-mode) ms-dos (arc-mode) editing (hideshow dcl-mode arc-mode) major-mode (dcl-mode arc-mode) extensions (use-package cookie1 qp gnus tq tabulated-list ring regi regexp-opt pcase nadvice map emacs let-alist ewoc eldoc cl-lib benchmark avl-tree calc type-break tree-widget transient thingatpt tempo strokes skeleton password-cache jsonrpc ido emacs-lock electric ehelp bind-key array) news (newsticker mailcap yenc uudecode supercite mail-utils footnote binhex emacs compface gnus time-date timezone auth-source) mouse (artist goto-addr browse-url xt-mouse window-tool-bar emacs thingatpt t-mouse strokes msb mouse-drag mouse-copy ffap avoid) hardware (zeroconf dbus emacs flow-ctrl battery) keys (bind-key) keybinding (bind-key) config (use-package bind-key) dotemacs (use-package bind-key) internal (emacs-authors-mode emacs warnings syntax smie disass select novice loadhist) hypermedia (url sgml-mode mhtml-mode less-css-mode css-mode org nxml soap-client browse-url emacs htmlfontify ffap) tools (vc smerge-mode log-view emerge ediff diff cvs-status add-log use-package emacs-news-mode which-func make-mode hideshow gud grep glasses gdb-mi flymake flymake-proc etags etags-regen erts-mode ebrowse cpp compile bug-reference reporter mail-utils trace re-builder package package-vc nadvice ert ert-font-lock elp eieio edebug debug copyright emacs check-declare backtrace semantic time-stamp thread tempo speedbar skeleton pcomplete imenu format-spec find-file ezimage elide-head dframe calculator) i18n (po emacs gnus double descr-text) data (url remember page-ext org snmp-mode bindat timeclock xml xdg whitespace registry jka-compr emacs hexl hex-util cdl) matching (regi re-builder thingatpt soundex misearch emacs hi-lock find-file ffap char-fold) faces (enriched m4-mode ld-script cwarn cpp gnus faceup emacs paren hl-line hilit-chg hi-lock face-remap descr-text color) color (htmlfontify color) hex (color) rgb (htmlfontify color) hsv (color) hsl (color) cie-lab (color) background (color) mule (emacs ps-print) multilingual (emacs descr-text) character\ composition (emacs) expand (dabbrev) completion (crm dabbrev) emulations (viper edt cua-base emacs hl-line delsel) unicode (emacs descr-text) file (dns-mode speedbar ezimage dframe) tags (ebrowse semantic ede speedbar ezimage dframe) dired (wdired emacs) window (emacs windmove follow) drag (emacs) drop (emacs) pdf (doc-view) ps (doc-view) dvi (doc-view) djvu (doc-view) epub (doc-view) cbz (doc-view) fb2 (doc-view) xps (doc-view) openxps (doc-view) xml (nxml xml dom) html (html-ts-mode shr shr-color eww gnus htmlfontify dom) font (ps-print emacs) system-font (emacs) tool-bar-style (emacs) mail (fortune rfc2104 puny pop3 mairix mailcap imap goto-addr mh-e unrmail undigest supercite smtpmail sendmail rmail rfc822 rfc6068 reporter qp mspools mail-utils mailclient mailalias mailabbrev ietf-drums hashcash footnote flow-fill feedmail emacs gnus time-date epa ecomplete) editorconfig (editorconfig) unix (emerge ediff diff sh-script make-mode gud gdb-mi executable cc-mode telnet woman tar-mode sort proced emacs lpr locate find-lisp find-dired) message (feedmail gnus epa) face\ remapping (face-remap) display (hi-lock follow face-remap) user\ commands (face-remap) filesets (filesets) c (hideshow hideif flymake flymake-proc flymake-cc cwarn cpp cmacexp cc-mode cc-guess c-ts-mode emacs find-file) folding (org foldout) minor-mode (hi-lock follow) frames (winner emacs talk tab-bar hl-line) generic (emacs) comment (emacs) font-lock (emacs) markup (htmlfontify) etags (htmlfontify) buffer (msb ibuffer) multimedia (mailcap image-dired image-crop gravatar compface gnus mpc emacs image-file iimage) docs (texnfo-upd texinfo texinfmt makeinfo lisp-mnt checkdoc info-xref) keyboard (keypad cua-base kmacro) md4 (md4) utilities (midnight) menu (erc msb) uncomment (emacs) desktop (notifications) notifications (notifications) obarray (emacs) functions (find-func emacs) print (handwrite ps-print printing) postscript (ps-mode ebnf2ps handwrite gnus ps-print printing) bdf (ps-print) multibyte (ps-print) vi (repeat) repeat (repeat) minibuffer (crm savehist emacs) bookmarks (saveplace) placeholders (saveplace) scroll (scroll-all) lock (scroll-all) spreadsheet (testcover ses) dijkstra (ses) image (svg) gpm (t-mouse) linux (t-mouse) tabs (tab-line tab-bar) windows (conf-mode tab-line) thread (thread) treesit (emacs) tree-sitter (yaml-ts-mode toml-ts-mode html-ts-mode typescript-ts-mode rust-ts-mode ruby-ts-mode php-ts-mode lua-ts-mode json-ts-mode java-ts-mode heex-ts-mode go-ts-mode elixir-ts-mode dockerfile-ts-mode cmake-ts-mode c-ts-mode emacs) timers (type-break) virtual\ cursor (vcursor) environment (wdired) renaming (wdired) movement (windmove) utility (unsafep testcover yank-media) calendar (org gnus todo-mode timeclock calendar icalendar diary-lib) holidays (calendar) dates (iso8601) util (ietf-drums time-date parse-time) todo (remember todo-mode) oo (eieio eieio-core chart cedet) project (semantic ede) make (semantic ede) syntax (emacs semantic mode-local) codegeneration (srecode) scheme (org ede) vc (vc smerge-mode pcvs log-view log-edit emerge ediff diff diff-mode cvs-status compare-w add-log url ede) data\ structures (avl-tree) avl (avl-tree) tree (cvs-status avl-tree) maint (texnfo-upd texinfo texinfmt reporter emacs edebug debug copyright compat checkdoc check-declare backtrace) chart (chart) graph (chart) multiple\ elements (crm) backtrace (emacs) bootstrap. (emacs) debugging (elp) emacs-lisp (find-func) variables (find-func) elisp (emacs) icons (icons) buttons (icons) compiler (macroexp) macros (macroexp) strings (regexp-opt) regexps (regexp-opt) sequences (thunk seq) parsing (smie) indentation (smie) safety (unsafep) cua (cua-base) mark (cua-base) irc (org erc) chat (erc) client (erc) internet (erc) button (erc) url (vc url erc) regexp (nxml erc) logging (erc) timestamp (erc) cancel-lock (gnus) hmac (hmac-md5 hmac-def gnus) sha1 (gnus) rfc2104 (hmac-md5 hmac-def gnus) web (gnus) icalendar (gnus) org (org gnus) xpm (gnus) annotation (gnus) glyph (gnus) registry (gnus) hz (emacs gnus) hz+ (emacs gnus) network (nsm network-stream net-utils dns dictionary-connection gnus) external-body (gnus) partial (gnus) uudecode (uudecode gnus) binhex (binhex gnus) shar (gnus) forward (gnus) gnatsweb (gnus) gnus (gnus) mime (gnus) s/mime (gnus) mml (gnus) searching (mairix gnus) rss (newsticker gnus) smime (gnus) x.509 (gnus) pem (gnus) openssl (gnus) spam (mh-e rmail gnus) gmane (gnus) report (gnus) bogofilter (gnus) bbdb (gnus) dspam (gnus) dig (dig gnus) whitelist (gnus) blacklist (gnus) hashcash (hashcash gnus) spamassassin (gnus) bsfilter (gnus) ifile (gnus) stat (gnus) crm114 (gnus) spamoracle (gnus) images (wallpaper image-converter exif) ccl (emacs) character\ set (emacs) coding-system (emacs) multibyte\ character (emacs) category (emacs) fun (emacs) fontset (emacs) isearch (emacs) tex (tildify texnfo-upd texinfo texinfmt tex-mode reftex refbib bibtex bibtex-style meta-mode org emacs) iso (emacs) latin (emacs) japanese (emacs) kinsoku (emacs) coding\ system (emacs) latex (bibtex emacs) charset (emacs) diagnosis (emacs) input\ method (emacs) quail (emacs) tit (emacs) cxterm (emacs) normalization (emacs) burma (emacs) cham (emacs) chinese (emacs) cyrillic (emacs) czech (emacs) ethiopic (emacs) european (emacs) greek (emacs) korean (emacs) hanja (emacs) hebrew (emacs) indian (emacs) devanagari (emacs) indonesia (emacs) khmer (emacs) lao (emacs) philippines (emacs) romanian (emacs) sinhala (emacs) slovak (emacs) tai\ viet (emacs) thai (emacs) word\ break (emacs) emacs (emacs) tibetan (emacs) vietnamese (emacs) email (rmail feedmail) queue (feedmail) sendmail (feedmail) spray (feedmail) smtp (feedmail) draft (feedmail) history (mail-utils) filter (rmail) rmail (rmail) yenc (yenc) hypertext (browse-url) interface (dictionary) dictionary (dictionary) dns (dns-mode dig) bind (dig) tls (gnutls) ssl (gnutls) encryption (nsm gnutls) www (webjump goto-addr) hmac-md5 (hmac-md5) md5 (hmac-md5) keyed-md5 (hmac-md5) cram-md5 (sasl hmac-md5) atom (newsticker) security (nsm) ntlm (sasl ntlm) sasl (sasl ntlm) net (puny) digest-md5 (sasl) password (secrets) passphrase (secrets) soap (soap-client) web-services (soap-client) firewalls (socks) relaxng (nxml) literate\ programming (org) reproducible\ research (org) r (org) statistics (org) comint (org) forth (org) fortran (fortran f90 org) js (org) scientific\ computing (org) babel\ language (org) maxima (org) interactive\ shell (org) capture (org) link (org) eww (org) erc (org) git (org) attachment (org) visibility\ cycling (org) invisible\ text (org) cache (org) storage (org) tables (org) plotting (org) emacsclient (org) markdown (org) games (zone tetris studly spook solitaire snake pong mpuz morse life hanoi gomoku gametree gamegrid fortune dunnet doctor dissociate decipher cookie1 bubbles blackbox animate 5x5) puzzles (5x5) utils (fortune) cursive\ writing (handwrite) antlr (antlr-mode) code\ generator (antlr-mode) c++ (hideshow ebrowse c-ts-mode emacs) java (conf-mode java-ts-mode hideshow emacs) javascript (js emacs) rust (rust-ts-mode emacs) cpp (c-ts-mode) awk (cc-mode) cc-mode (cc-mode) oop (csharp-mode cc-guess) cmake (cmake-ts-mode) perl (cperl-mode) c\# (csharp-mode) dcl (dcl-mode) dockerfile (dockerfile-ts-mode) ebnf (ebnf2ps) elixir (heex-ts-mode elixir-ts-mode) f90 (f90) go (go-ts-mode) comments (hideshow) blocks (hideshow) hiding (hideshow) json (json-ts-mode) lua (lua-ts-mode) metafont (meta-mode) metapost (meta-mode) knuth (mixal-mode) mix (mixal-mode) mixal (mixal-mode) asm (mixal-mode) mixvm (mixal-mode) the\ art\ of\ computer\ programming (mixal-mode) php (php-ts-mode) language (php-ts-mode) prolog (prolog) major (prolog) mode (prolog) sicstus (prolog) swi (prolog) mercury (prolog) ruby (ruby-ts-mode ruby-mode) tcl (tcl) modes (tcl) typescript (typescript-ts-mode) tsx (typescript-ts-mode) vera (vera-mode) vhdl (vhdl-mode) mode-line (which-func) imenu (which-func) bib (refer refbib bib-mode) bibtex (bibtex) conf (conf-mode) ini (conf-mode) master (dns-mode) zone (dns-mode) soa (dns-mode) filling (pixel-fill) memory (remember) pim (remember) sgml (tildify) toml (toml-ts-mode) yaml (yaml-ts-mode) startup (use-package) speed (use-package) package (use-package) pcl-cvs (pcvs log-edit cvs-status) cvs (smerge-mode pcvs log-edit cvs-status) status (cvs-status) patch (diff-mode) diff (diff-mode) comparing (ediff) merging (ediff) patching (ediff) commit (log-edit) log (log-edit) release\ management (pcvs) revision\ control (smerge-mode) merge (smerge-mode) diff3 (smerge-mode) conflict (smerge-mode))))

(provide 'finder-inf)

;; Local Variables:
;; version-control: never
;; no-byte-compile: t
;; no-update-autoloads: t
;; coding: utf-8-emacs-unix
;; End:

;;; finder-inf.el ends here
